@@ -227,7 +227,7 @@ class JaxDQNAgent(object):
                seed=None,
                loss_type='mse',
                preprocess_fn=None,
-               collector_allowlist=('tensorboard')):
+               collector_allowlist=('tensorboard',)):
     """Initializes the agent and constructs the necessary components.
 
     Note: We are using the Adam optimizer by default for JaxDQN, which differs
@@ -289,6 +289,8 @@ class JaxDQNAgent(object):
     logging.info('\t seed: %d', seed)
     logging.info('\t loss_type: %s', loss_type)
     logging.info('\t preprocess_fn: %s', preprocess_fn)
+    logging.info('\t summary_writing_frequency: %d', summary_writing_frequency)
+    logging.info('\t allow_partial_reload: %s', allow_partial_reload)
 
     self.num_actions = num_actions
     self.observation_shape = tuple(observation_shape)
@@ -509,7 +511,7 @@ class JaxDQNAgent(object):
           if hasattr(self, 'collector_dispatcher'):
             self.collector_dispatcher.write(
                 [statistics_instance.StatisticsInstance(
-                    'Loss', loss.to_py(), step=self.training_steps),
+                    'Loss', onp.asarray(loss), step=self.training_steps),
                  ],
                 collector_allowlist=self._collector_allowlist)
       if self.training_steps % self.target_update_period == 0:
@@ -650,4 +652,4 @@ class JaxDQNAgent(object):
     self.collector_dispatcher = collector_dispatcher
     # Ensure we have a collector allowlist defined.
     if not hasattr(self, '_collector_allowlist'):
-      self._collector_allowlist = ('tensorboard')
+      self._collector_allowlist = ('tensorboard',)
